@@ -326,8 +326,9 @@ class EssClient(AbstractClient):
 
 
     def CreateFlowEvidenceReport(self, request):
-        """创建出证报告，返回报告 ID。需要配合出证套餐才能调用。
-        出证需要一定时间，建议调用创建出证24小时之后再通过DescribeFlowEvidenceReport进行查询。
+        """创建出证报告并返回报告ID。
+        使用此功能需搭配出证套餐。
+        注意：出证过程需一定时间，建议在调用创建出证后的24小时之后，通过DescribeFlowEvidenceReport接口进行查询。
 
         :param request: Request instance for CreateFlowEvidenceReport.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowEvidenceReportRequest`
@@ -399,11 +400,13 @@ class EssClient(AbstractClient):
 
 
     def CreateFlowReminds(self, request):
-        """指定需要批量催办的签署流程Id，批量催办合同，最多100个; 接口失败后返回错误信息
-        注意:
-        该接口不可直接调用，请联系客户经理申请使用
-        仅能催办当前状态为“待签署”的签署人，且只能催办一次
-        发起合同时，签署人的NotifyType需设置为sms，否则无法催办
+        """指定需要批量催办的签署流程ID，批量催办合同，最多100个。需要符合以下条件的合同才可被催办：
+
+        1. 发起合同时，签署人的NotifyType需设置为sms
+        2. 合同中当前状态为“待签署”的签署人是催办的对象
+        3. 每个合同只能催办一次
+
+        注意：该接口无法直接调用，请联系客户经理申请使用。
 
         :param request: Request instance for CreateFlowReminds.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowRemindsRequest`
@@ -504,7 +507,8 @@ class EssClient(AbstractClient):
 
 
     def CreateIntegrationEmployees(self, request):
-        """创建员工,此接口会发送提醒员工实名的短信
+        """创建员工,此接口会发送提醒员工实名的短信，如果通过手机号发现员工已经创建，则不会重新创建，会发送短信提醒员工实名
+        注意：此接口支持企微组织架构的 openid 创建员工，这种场景下传递明文的企微 openid 到WeworkOpenId字段即可（企微明文的 openid 一定要在应用的可见范围内才行），通过企微创建的员工，会发送企微消息去提醒实名
 
         :param request: Request instance for CreateIntegrationEmployees.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateIntegrationEmployeesRequest`
@@ -526,6 +530,38 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateIntegrationRole(self, request):
+        """此接口（CreateIntegrationRole）用来创建企业自定义的SaaS角色或集团角色。
+
+        适用场景1：创建当前企业的自定义SaaS角色或集团角色，并且创建时不进行权限的设置（PermissionGroups 参数不传），角色中的权限内容可通过控制台编辑角色或通过接口 ModifyIntegrationRole 完成更新。
+
+        适用场景2：创建当前企业的自定义SaaS角色或集团角色，并且创建时进行权限的设置（PermissionGroups 参数要传），权限树内容 PermissionGroups 可参考接口 DescribeIntegrationRoles 的输出。
+        适用场景3：创建集团角色时可同时设置角色管理的子企业列表，可通过设置 SubOrganizationIds 参数达到此效果。
+
+        适用场景4：主企业代理子企业操作的场景，需要设置Agent参数，并且ProxyOrganizationId设置为子企业的id即可。
+
+        注意事项：SaaS角色和集团角色对应的权限树是不一样的。
+
+        :param request: Request instance for CreateIntegrationRole.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateIntegrationRoleRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateIntegrationRoleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateIntegrationRole", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateIntegrationRoleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateIntegrationUserRoles(self, request):
         """绑定员工与对应角色
 
@@ -560,6 +596,10 @@ class EssClient(AbstractClient):
         - B端企业的签署方式是静默签署
         - B端企业是非首位签署
 
+         通过一码多扫二维码发起的合同，涉及到的合同回调消息可参考文档[合同发起以及签署相关回调](https://qian.tencent.com/developers/company/callback_types_contracts_sign)
+
+        用户通过签署二维码发起合同时，因企业额度不足导致失败 会触发签署二维码相关回调,具体参考文档[签署二维码相关回调](https://qian.tencent.com/developers/company/callback_types_commons#%E7%AD%BE%E7%BD%B2%E4%BA%8C%E7%BB%B4%E7%A0%81%E7%9B%B8%E5%85%B3%E5%9B%9E%E8%B0%83)
+
         :param request: Request instance for CreateMultiFlowSignQRCode.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateMultiFlowSignQRCodeRequest`
         :rtype: :class:`tencentcloud.ess.v20201111.models.CreateMultiFlowSignQRCodeResponse`
@@ -732,7 +772,7 @@ class EssClient(AbstractClient):
 
 
     def CreateSeal(self, request):
-        """创建电子印章
+        """本接口（CreateSeal）用于创建企业电子印章，支持创建企业公章，合同章，财务专用章和人事专用章创建。
 
         :param request: Request instance for CreateSeal.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateSealRequest`
@@ -848,6 +888,9 @@ class EssClient(AbstractClient):
 
     def DeleteIntegrationEmployees(self, request):
         """移除员工
+        这里分两个场景
+        如果不传交接人的ReceiveUserId或者ReceiveOpenId，则会直接把这个人进行离职
+        如果传了交接人，会把离职人未处理完的合同交接给交接人后再离职
 
         :param request: Request instance for DeleteIntegrationEmployees.
         :type request: :class:`tencentcloud.ess.v20201111.models.DeleteIntegrationEmployeesRequest`
@@ -965,7 +1008,7 @@ class EssClient(AbstractClient):
     def DescribeFlowBriefs(self, request):
         """查询流程基础信息
         适用场景：可用于主动查询某个合同流程的签署状态信息。可以配合回调通知使用。
-        每个企业限制日调用量限制：10W,  当当日超过此限制后再调用接口返回错误
+        每个企业限制日调用量限制：100W，当日超过此限制后再调用接口返回错误
 
         :param request: Request instance for DescribeFlowBriefs.
         :type request: :class:`tencentcloud.ess.v20201111.models.DescribeFlowBriefsRequest`
@@ -988,7 +1031,7 @@ class EssClient(AbstractClient):
 
 
     def DescribeFlowComponents(self, request):
-        """查询流程填写控件内容，可以根据流程Id查询该流程相关联的填写控件信息
+        """查询流程填写控件内容，可以根据流程Id查询该流程相关联的填写控件信息和填写内容。
 
         :param request: Request instance for DescribeFlowComponents.
         :type request: :class:`tencentcloud.ess.v20201111.models.DescribeFlowComponentsRequest`
@@ -1011,7 +1054,7 @@ class EssClient(AbstractClient):
 
 
     def DescribeFlowEvidenceReport(self, request):
-        """查询出证报告，返回报告 URL。
+        """查询出证报告，返回报告 URL。出证报告编号通过CreateFlowEvidenceReport接口获取。
 
         :param request: Request instance for DescribeFlowEvidenceReport.
         :type request: :class:`tencentcloud.ess.v20201111.models.DescribeFlowEvidenceReportRequest`
@@ -1164,7 +1207,7 @@ class EssClient(AbstractClient):
 
 
     def DescribeIntegrationRoles(self, request):
-        """查询企业角色列表
+        """分页查询企业角色列表，法人的角色是系统保留角色，不会返回，按照角色创建时间升序排列
 
         :param request: Request instance for DescribeIntegrationRoles.
         :type request: :class:`tencentcloud.ess.v20201111.models.DescribeIntegrationRolesRequest`
@@ -1374,6 +1417,38 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyIntegrationRole(self, request):
+        """此接口（ModifyIntegrationRole）用来更新企业自定义的SaaS角色或集团角色。
+
+        适用场景1：更新当前企业的自定义SaaS角色或集团角色，并且更新时不进行角色中权限的更新（PermissionGroups 参数不传）。
+
+        适用场景2：更新当前企业的自定义SaaS角色或集团角色，并且更新时进行角色中权限的设置（PermissionGroups 参数要传），权限树内容 PermissionGroups 可参考接口 DescribeIntegrationRoles 的输出。
+        适用场景3：更新集团角色管理的子企业列表，可通过设置 SubOrganizationIds 参数达到此效果。
+
+        适用场景4：主企业代理子企业操作的场景，需要设置Agent参数，并且ProxyOrganizationId设置为子企业的id即可。
+
+        注意事项：SaaS角色和集团角色对应的权限树是不一样的。
+
+        :param request: Request instance for ModifyIntegrationRole.
+        :type request: :class:`tencentcloud.ess.v20201111.models.ModifyIntegrationRoleRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.ModifyIntegrationRoleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyIntegrationRole", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyIntegrationRoleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def StartFlow(self, request):
         """此接口用于发起流程
         适用场景：见创建签署流程接口。
@@ -1476,7 +1551,7 @@ class EssClient(AbstractClient):
 
 
     def VerifyPdf(self, request):
-        """对流程的合同文件进行验证，判断文件是否合法。
+        """对流程的合同文件进行数字签名验证，判断文件是否被篡改。
 
         :param request: Request instance for VerifyPdf.
         :type request: :class:`tencentcloud.ess.v20201111.models.VerifyPdfRequest`
